#!/usr/bin/python
# -*- coding: utf-8 -*-
from today.spider import HuangliSpider



def show_chinese_day():
   year , month , day ,time = HuangliSpider().get_current_calender()
   print("{} {} {} {}".format(year,month,day,time))





def main():
    show_chinese_day()














if __name__ == '__main__':
    main()




#!/usr/bin/python
# -*- coding: utf-8 -*-
import requests
import re


class SpiderBase(object):

    headers = {"User-Agent":"Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/88.0.4324.192 Safari/537.36"}


class HuangliSpider(SpiderBase):

    api_url = "https://nongli.911cha.com/"

    def get_current_calender(self):
        html = requests.get(self.api_url,headers=self.headers).text
        re_pattern = "今日.*?年柱.*?<br />(.*?)</td>.*?月柱.*?<br />(.*?)</td>.*?日柱.*?<br />(.*?)</td>.*?时柱.*?<br />(.*?)</td>"
        r = re.search(re_pattern,html.encode("utf-8"))
        return r.group(1),r.group(2),r.group(3),r.group(4)



if __name__ == '__main__':
    a = HuangliSpider()
    print(a.get_current_calender())



import setuptools

setuptools.setup(
    name="today-calender",
    version="0.0.3",
    author="lindaye",
    author_email="454784911@qq.com",
    description="基于爬虫的历法查询工具",
    long_description="一个展示当日老黄历的命令行工具\n输入命令: td",
    url="https://github.com/stellaye/today",
    packages=["today"],
    entry_points={'console_scripts': [
            'td = today.main:main',
        ]},
    classifiers=[
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7'
    ],
)
